clear all; close all; clc
% ===============================
% ==== Calcule the significances of the cold event anomalies
% ===============================

% ==== VARIABLES. Anomalies and smoothing previously calculated with Ferret

% == Oceanic grid
%var1 = ncread('/scratch/local1/m300281/control/ocean/thetao/tos_Oyr_MPI-ESM-P_piControl_r1i1p1_1850-3005_1degreegrid.nc','tos');
%var1 = ncread('/scratch/local1/m300281/control/ocean/mstrans_Oyr_MPI-ESM-P_piControl_r1i1p1_1850-3005_1degreegrid.nc','MSTRANS');
%var1 = ncread('/scratch/local1/m300281/control/atmos/curl_Ayr_MPI-ESM-P_piControl_r1i1p1_1850-3005.nc','CURL');
%var1 = ncread('/scratch/local1/m300281/control/ocean/amoc_Oyr_MPI-ESM-P_piControl_r1i1p1_1850-3005_1degreegrid.nc','atlantic_moc'); var1 = squeeze(var1)*(1e-6)/1024;
%var1 = ncread('/scratch/local1/m300281/control/ocean/sos_Oyr_MPI-ESM-P_piControl_r1i1p1_1850-3005_1degreegrid.nc','sos');
%var1 = ncread('/scratch/local1/m300281/control/march/zmld_OMarch_MPI-ESM-P_piControl_r1i1p1_185003-300503_1deg.nc','zmld');
%var1 = ncread('/scratch/local1/m300281/control/winter/psl_ADJF_MPI-ESM-P_piControl_r1i1p1_1851_3004.nc','psl');
%var1 = ncread('/scratch/local1/m300281/control/atmos/ts_Ayr_MPI-ESM-P_piControl_r1i1p1_1850-3005.nc','ts');
var1 = ncread('/scratch/local1/m300281/control/march/sic_OIMarch_MPI-ESM-P_piControl_r1i1p1_185003-300503_1deg.nc','sic');

% ==== Count the number of NaN years. The selected point must have real values
time    = var1(60,30,:);
NN      = length(var1(60,30,:));
NT      = length(time(isfinite(time)));

clear time

% ==== DEFINE THE CONFIDENCE LEVEL. Usually 5 95, 1 99
conflevel = [5 95];
rep = 500;  % Number of repetitions

% ==== MONTECARLO REPETITION
campo = zeros(size(var1,1),size(var1,2),rep);

M = sort(randi([201 NT-100],[rep,1]));
Af = []; Be=[];
for t=1:rep; for z=1:100; Af(t,z)=M(t)+z-1; end; end;
for t=1:rep; for z=1:100; Be(t,z)=Af(t,z)+z-200-1; end; end; 
clear t z


for i=1:size(var1,1); 
    for j=1:size(var1,2);
        for t=1:rep
            if isnan(var1(i,j,t))==1
               campo(i,j,t)=NaN;
            elseif isnan(var1(i,j,t))==0
                campo(i,j,t) = nanmean(var1(i,j,Af(t,:))) - nanmean(var1(i,j,Be(t,:)));
            end
        end
    end
end

sigmax  = prctile(campo,conflevel(2),3); sigmax = sigmax';
sigmin  = prctile(campo,conflevel(1),3); sigmin = sigmin';

clear i j z t sst M N J AA conflevel NN NT NC campo ans

% ==== END CALCULATION

% ======= 4th STEP:  PLOT AND SAVE
contourf(sigmax)%-sigmin)
%save('dvariable-PiControl_sigmin-95_diff100years-after-before.dat','sigmin','-ascii');
%save('dvariable-PiControl_sigmax-95_diff100years-after-before.dat','sigmax','-ascii');


